==> gnuhealth-client-4.2.0.tar.gz: gnuhealth-client-4.2.0/gnuhealth/common/__init__.py <==
#########################################################################
#             GNU HEALTH HOSPITAL MANAGEMENT - GTK CLIENT               #
#                      https://www.gnuhealth.org                        #
#########################################################################
#       The GNUHealth HMIS client based on the Tryton GTK Client        #
#########################################################################
#
# SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
# SPDX-FileCopyrightText: 2017-2023 GNU Health Community <info@gnuhealth.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later


# This file is part of GNU Health.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from .common import (
    IconFactory, MODELACCESS, MODELHISTORY, MODELNAME, VIEW_SEARCH,
    get_toplevel_window, get_sensible_widget, selection, file_selection,
    slugify, file_write, file_open, mailto, message, warning, userwarning, sur,
    sur_3b, ask, concurrency, error, to_xml, process_exception, Login, Logout,
    node_attributes, hex2rgb, highlight_rgb, generateColorscheme, RPCException,
    RPCProgress, RPCExecute, RPCContextReload, Tooltips, COLOR_SCHEMES,
    filter_domain, timezoned_date, untimezoned_date, humanize, get_hostname,
    get_port, resize_pixbuf, data2pixbuf, apply_label_attributes, ellipsize,
    get_align, date_format, idle_add, check_version, GNUHEALTH_ICON, setup_window)
from .domain_inversion import (
    domain_inversion, eval_domain, localize_domain, merge, inverse_leaf,
    filter_leaf, prepare_reference_domain, extract_reference_models, concat,
    simplify, unique_value)
from .environment import EvalEnvironment
from . import timedelta

__all__ = [
    IconFactory, MODELACCESS, MODELHISTORY, MODELNAME, VIEW_SEARCH,
    get_toplevel_window, get_sensible_widget, selection, file_selection,
    slugify, file_write, file_open, mailto, message, warning, userwarning, sur,
    sur_3b, ask, concurrency, error, to_xml, process_exception, Login, Logout,
    node_attributes, hex2rgb, highlight_rgb, generateColorscheme, RPCException,
    RPCProgress, RPCExecute, RPCContextReload, Tooltips, COLOR_SCHEMES,
    filter_domain, timezoned_date, untimezoned_date, humanize, get_hostname,
    get_port, resize_pixbuf, data2pixbuf, apply_label_attributes, ellipsize,
    get_align, date_format, idle_add, domain_inversion, eval_domain,
    localize_domain, merge, inverse_leaf, filter_leaf,
    prepare_reference_domain, extract_reference_models, concat, simplify,
    unique_value, EvalEnvironment, timedelta, check_version, GNUHEALTH_ICON,
    setup_window]

==> gnuhealth-client-4.2.1.tar.gz: gnuhealth-client-4.2.1/gnuhealth/common/__init__.py <==
#########################################################################
#             GNU HEALTH HOSPITAL MANAGEMENT - GTK CLIENT               #
#                      https://www.gnuhealth.org                        #
#########################################################################
#       The GNUHealth HMIS client based on the Tryton GTK Client        #
#########################################################################
#
# SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
# SPDX-FileCopyrightText: 2017-2023 GNU Health Community <info@gnuhealth.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later


# This file is part of GNU Health.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from .common import (
    IconFactory, MODELACCESS, MODELHISTORY, MODELNAME, VIEW_SEARCH,
    get_toplevel_window, get_sensible_widget, selection, file_selection,
    slugify, file_write, file_open, mailto, message, warning, userwarning, sur,
    sur_3b, ask, concurrency, error, to_xml, process_exception, Login, Logout,
    node_attributes, hex2rgb, highlight_rgb, generateColorscheme, RPCException,
    RPCProgress, RPCExecute, RPCContextReload, Tooltips, COLOR_SCHEMES,
    filter_domain, timezoned_date, untimezoned_date, humanize, get_hostname,
    get_port, resize_pixbuf, data2pixbuf, apply_label_attributes, ellipsize,
    get_align, date_format, idle_add, check_version, GNUHEALTH_ICON, setup_window,
    get_gdk_backend)
from .domain_inversion import (
    domain_inversion, eval_domain, localize_domain, merge, inverse_leaf,
    filter_leaf, prepare_reference_domain, extract_reference_models, concat,
    simplify, unique_value)
from .environment import EvalEnvironment
from . import timedelta

__all__ = [
    IconFactory, MODELACCESS, MODELHISTORY, MODELNAME, VIEW_SEARCH,
    get_toplevel_window, get_sensible_widget, selection, file_selection,
    slugify, file_write, file_open, mailto, message, warning, userwarning, sur,
    sur_3b, ask, concurrency, error, to_xml, process_exception, Login, Logout,
    node_attributes, hex2rgb, highlight_rgb, generateColorscheme, RPCException,
    RPCProgress, RPCExecute, RPCContextReload, Tooltips, COLOR_SCHEMES,
    filter_domain, timezoned_date, untimezoned_date, humanize, get_hostname,
    get_port, resize_pixbuf, data2pixbuf, apply_label_attributes, ellipsize,
    get_align, date_format, idle_add, domain_inversion, eval_domain,
    localize_domain, merge, inverse_leaf, filter_leaf,
    prepare_reference_domain, extract_reference_models, concat, simplify,
    unique_value, EvalEnvironment, timedelta, check_version, GNUHEALTH_ICON,
    setup_window, get_gdk_backend]
